#[repr(i32)]pub enum PresetFormat {
Show 45 variants
None = 0,
Gray8 = 268_959_744,
Gray9 = 269_025_280,
Gray10 = 269_090_816,
Gray12 = 269_221_888,
Gray14 = 269_352_960,
Gray16 = 269_484_032,
Gray32 = 270_532_608,
GrayH = 286_261_248,
GrayS = 287_309_824,
YUV410P8 = 805_831_170,
YUV411P8 = 805_831_168,
YUV440P8 = 805_830_657,
YUV420P8 = 805_830_913,
YUV422P8 = 805_830_912,
YUV444P8 = 805_830_656,
YUV420P9 = 805_896_449,
YUV422P9 = 805_896_448,
YUV444P9 = 805_896_192,
YUV420P10 = 805_961_985,
YUV422P10 = 805_961_984,
YUV444P10 = 805_961_728,
YUV420P12 = 806_093_057,
YUV422P12 = 806_093_056,
YUV444P12 = 806_092_800,
YUV420P14 = 806_224_129,
YUV422P14 = 806_224_128,
YUV444P14 = 806_223_872,
YUV420P16 = 806_355_201,
YUV422P16 = 806_355_200,
YUV444P16 = 806_354_944,
YUV420PH = 823_132_417,
YUV420PS = 824_180_993,
YUV422PH = 823_132_416,
YUV422PS = 824_180_992,
YUV444PH = 823_132_160,
YUV444PS = 824_180_736,
RGB24 = 537_395_200,
RGB27 = 537_460_736,
RGB30 = 537_526_272,
RGB36 = 537_657_344,
RGB42 = 537_788_416,
RGB48 = 537_919_488,
RGBH = 554_696_704,
RGBS = 555_745_280,
}Expand description
Preset VapourSynth formats.
The presets suffixed with H and S have floating point sample type. The H and S suffixes stand for half precision and single precision, respectively.
Format IDs in VapourSynth v4 are computed using the formula:
(colorFamily << 28) | (sampleType << 24) | (bitsPerSample << 16) | (subSamplingW << 8) | (subSamplingH << 0)
Variants
None = 0
Gray8 = 268_959_744
Gray9 = 269_025_280
Gray10 = 269_090_816
Gray12 = 269_221_888
Gray14 = 269_352_960
Gray16 = 269_484_032
Gray32 = 270_532_608
GrayH = 286_261_248
GrayS = 287_309_824
YUV410P8 = 805_831_170
YUV411P8 = 805_831_168
YUV440P8 = 805_830_657
YUV420P8 = 805_830_913
YUV422P8 = 805_830_912
YUV444P8 = 805_830_656
YUV420P9 = 805_896_449
YUV422P9 = 805_896_448
YUV444P9 = 805_896_192
YUV420P10 = 805_961_985
YUV422P10 = 805_961_984
YUV444P10 = 805_961_728
YUV420P12 = 806_093_057
YUV422P12 = 806_093_056
YUV444P12 = 806_092_800
YUV420P14 = 806_224_129
YUV422P14 = 806_224_128
YUV444P14 = 806_223_872
YUV420P16 = 806_355_201
YUV422P16 = 806_355_200
YUV444P16 = 806_354_944
YUV420PH = 823_132_417
YUV420PS = 824_180_993
YUV422PH = 823_132_416
YUV422PS = 824_180_992
YUV444PH = 823_132_160
YUV444PS = 824_180_736
RGB24 = 537_395_200
RGB27 = 537_460_736
RGB30 = 537_526_272
RGB36 = 537_657_344
RGB42 = 537_788_416
RGB48 = 537_919_488
RGBH = 554_696_704
RGBS = 555_745_280